Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/uplot_simpletest.py
    :caption: examples/uplot_simpletest.py
    :linenos:

.. image:: ../docs/uplot_ex1.jpg

Plot Example
-------------

Pot some data for x and y

.. literalinclude:: ../examples/uplot_plot_example.py
    :caption: examples/uplot_plot_example.py
    :linenos:

.. image:: ../docs/uplot_ex4.jpg

Tick Parameters Settings Example
----------------------------------

Setting up the ticks parameters

.. literalinclude:: ../examples/uplot_tickparameters.py
    :caption: examples/uplot_tickparameters.py
    :linenos:

.. image:: ../docs/uplot_ex3.jpg

Integration Example
-------------------

Example showing different graphics elements integration

.. literalinclude:: ../examples/uplot_integration_example.py
    :caption: examples/uplot_integration_example.py
    :linenos:
.. image:: ../docs/uplot_ex5.jpg

Scatter Example
-------------------

Scatter plot Example

.. literalinclude:: ../examples/uplot_uscatter.py
    :caption: examples/uplot_uscatter.py
    :linenos:
.. image:: ../docs/uplot_ex7.jpg

Display_shapes Example
-----------------------

Display Shapes integration example

.. literalinclude:: ../examples/uplot_display_shapes.py
    :caption: examples/uplot_display_shapes.py
    :linenos:
.. image:: ../docs/uplot_ex6.jpg

Ubar Example
----------------

ubar example

.. literalinclude:: ../examples/uplot_ubar_example.py
    :caption: examples/uplot_ubar_example.py
    :linenos:
.. image:: ../docs/uplot_ex8.jpg
